BarcodeFormat class

条码格式

Inheritance
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

BarcodeFormat({int symbology = 0, int dotWidth = 0, int barHeight = 0, int readable = 0})
BarcodeFormat.fromJson(Map<String, dynamic> json)
从 JSON 创建 BarcodeFormat 实例
factory

Properties

align ↔ int
对齐方式
getter/setter pairinherited
barHeight ↔ int
条码高度
getter/setter pair
dotWidth ↔ int
条码宽度
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
height ↔ int
预打印内容的高度
getter/setter pairinherited
readable ↔ int
人类可读性的位置
getter/setter pair
renderColor ↔ int
指定渲染的颜色
getter/setter pairinherited
rotate ↔ int
旋转角度
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
symbology ↔ int
条码类型
getter/setter pair
width ↔ int
预打印内容的宽度
getter/setter pairinherited
xOffset ↔ int
在行打印中对应相对当前横向位置 在图打印中对应 x 轴坐标位置
getter/setter pairinherited
yOffset ↔ int
在行打印中对应相对上一行的位置 在图打印中对应 y 轴坐标位置
getter/setter pairinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
转换为 JSON
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited