AreaStyle class

Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

AreaStyle(AreaFormat areaFormat)
AreaStyle.fromJson(Map<String, dynamic> json)
factory

Properties

areaFormat → AreaFormat
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

format() → AreaFormat
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setEndX(int x) → AreaStyle
setEndY(int y) → AreaStyle
setHeight(int height) → AreaStyle
setPosX(int offset) → AreaStyle
setPosY(int offset) → AreaStyle
setStyle(Shape shape) → AreaStyle
setThick(int w) → AreaStyle
setWidth(int width) → AreaStyle
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

getStyle() → AreaStyle